@@ -29,13 +29,13 @@
 pem <- function(data, dvar, pvar, decreasing = FALSE, binom.test = TRUE, chi.test = FALSE, FUN = median, phases = c(1, 2), ...) {
 
   # set default attributes
-  if (missing(dvar)) dvar <- scdf_attr(data, .opt$dv)
-  if (missing(pvar)) pvar <- scdf_attr(data, .opt$phase)
-  scdf_attr(data, .opt$dv) <- dvar
-  scdf_attr(data, .opt$phase) <- pvar
+  if (missing(dvar)) dvar <- dv(data)
+  if (missing(pvar)) pvar <- phase(data)
+  dv(data) <- dvar
+  phase(data) <- pvar
   
   data <- .prepare_scdf(data, na.rm = TRUE)
-  data <- .keep_phases(data, phases = phases)$data
+  data <- recombine_phases(data, phases = phases)$data
   
   N <- length(data)
   
@@ -82,7 +82,7 @@ pem <- function(data, dvar, pvar, decreasing = FALSE, binom.test = TRUE, chi.tes
   
   out <- list(PEM = PEM, test = stats.ma, decreasing = decreasing)
   class(out) <- c("sc_pem")
-  attr(out, .opt$phase) <- pvar
-  attr(out, .opt$dv) <- dvar
+  attr(out, opt("phase")) <- pvar
+  attr(out, opt("dv")) <- dvar
   out
 }
