@@ -3,31 +3,29 @@
 #' Conducts a Monte-Carlo study on the test-power and alpha-error probability of
 #' a statistical function.
 #'
-#' Based on a \code{\link{design}} object, a large number of single-cases are
-#' generated and re-analyzed with a provided statistical function. The
-#' proportion of significant analyzes is the test power. In a second step, a
-#' specified effect of the design object is set to 0 and again single-cases are
-#' generated and reanalyzed. The proportion of significant analyzes is the alpha
-#' error probability.
+#' Based on a [design()] object, a large number of single-cases are generated
+#' and re-analyzed with a provided statistical function. The proportion of
+#' significant analyzes is the test power. In a second step, a specified effect
+#' of the design object is set to 0 and again single-cases are generated and
+#' reanalyzed. The proportion of significant analyzes is the alpha error
+#' probability.
 #'
 #' @param design An object returned from the `design` function.
 #' @param method A (named) list that defines the methods the power analysis is
 #'   based on. Each element can contain a function (that takes an scdf file and
 #'   returns a p value) or a character string (the name of predefined
-#'   functions). default \code{method = list("plm_level", "rand", "tauU")}
-#'   computes a power analysis based on \code{\link{tau_u}},
-#'   \code{\link{rand_test}} and \code{\link{plm}} analyses. (Further predefined
-#'   functions are: "plm_slope", "plm_poisson_level", "plm_poisson_slope",
-#'   "hplm_level", "hplm_slope", "base_tau".
+#'   functions). default `method = list("plm_level", "rand", "tauU")` computes a
+#'   power analysis based on [tau_u()], [rand_test()] and [plm()] analyses.
+#'   (Further predefined functions are: "plm_slope", "plm_poisson_level",
+#'   "plm_poisson_slope", "hplm_level", "hplm_slope", "base_tau".
 #' @param effect Either "level" or "slope". The respective effect of the
 #'   provided design is set to 0 when computing the alpha-error proportion.
 #' @param n_sim Number of sample studies created for the the Monte-Carlo study.
-#'   Default is \code{n = 100}. Ignored if design_is_one_study = FALSE.
+#'   Default is `n = 100`. Ignored if design_is_one_study = FALSE.
 #' @param design_is_one_study If TRUE, the design is assumed to define all cases
-#'   of one study that is repeatedly randomly created \code{n_sim} times. If
-#'   false, the design is assumed to contain all cases from which a random
-#'   sample is generated. This is useful for very specific complex simulation
-#'   studies.
+#'   of one study that is repeatedly randomly created `n_sim` times. If false,
+#'   the design is assumed to contain all cases from which a random sample is
+#'   generated. This is useful for very specific complex simulation studies.
 #' @param alpha_test Logical. If TRUE, alpha error is calculated.
 #' @param power_test Logical. If TRUE, power is calculated.
 #' @param binom_test Shortcut. When set TRUE, binom_test_power is set to 0.80,
@@ -45,9 +43,9 @@
 #'   intervals at the provided level are calculated for power, alpha error, and
 #'   correct proportions.
 #' @param alpha_level Alpha level used to calculate the proportion of
-#'   significant tests. Default is \code{alpha_level = 0.05}.
+#'   significant tests. Default is `alpha_level = 0.05`.
 #' @author Juergen Wilbert
-#' @seealso \code{\link{random_scdf}}, \code{\link{design}}
+#' @seealso [random_scdf()], [design()]
 #' @examples
 #'
 #' ## Assume you want to conduct a single-case study with 15 measurements
@@ -118,17 +116,17 @@ power_test <- function(design,
     
     design_no_effect <- design
     if (effect == "level") {
-      design_no_effect$cases <- lapply(
-        design_no_effect$cases, 
-        function(x) {x$level <- rep(0, length = length(x$length)); x}
-      )
+      design_no_effect$cases <- lapply(design_no_effect$cases,  function(x) {
+        x$level <- rep(0, length = length(x$length))
+        x
+      })
     }
     
     if (effect == "slope") {
-      design_no_effect$cases <- lapply(
-        design_no_effect$cases, 
-        function(x) {x$slope <- rep(0, length = length(x$length)); x}
-      )
+      design_no_effect$cases <- lapply(design_no_effect$cases, function(x) {
+        x$slope <- rep(0, length = length(x$length))
+        x
+      })
     }
     
     out$"Alpha Error" <- .mc_scdf(
@@ -138,7 +136,9 @@ power_test <- function(design,
       mc_fun = mc_fun,
       design_is_one_study = design_is_one_study
     )
-  } else out$"Alpha Error" <- NA
+  } else {
+    out$"Alpha Error" <- NA
+  }
   
   out$"Alpha:Beta" <- sprintf("1:%.1f", (100 - out$Power) / out$"Alpha Error")
   out$Correct <- (out$Power + (100 - out$"Alpha Error")) / 2
@@ -151,7 +151,11 @@ power_test <- function(design,
   
   if (is.numeric(binom_test_power)) {
     b_test <- function(x) {
-      x <- binom.test(round(x / 100 * n_sim), n_sim, p = binom_test_power, alternative = "greater")
+      x <- binom.test(round(x / 100 * n_sim), 
+        n_sim, 
+        p = binom_test_power, 
+        alternative = "greater"
+      )
       round(x$p.value)
     }
     out[["p_power"]] <- sapply(out$"Power", b_test)
@@ -159,7 +163,11 @@ power_test <- function(design,
   
   if (is.numeric(binom_test_alpha)) {
     b_test <- function(x) {
-      x <- binom.test(round(x / 100 * n_sim), n_sim, p = binom_test_alpha, alternative = "less")
+      x <- binom.test(round(x / 100 * n_sim), 
+        n_sim, 
+        p = binom_test_alpha, 
+        alternative = "less"
+      )
       round(x$p.value)
     }
     out[["p_alpha"]] <- sapply(out$"Alpha Error", b_test)
@@ -167,7 +175,11 @@ power_test <- function(design,
   
   if (is.numeric(binom_test_correct)) {
     b_test <- function(x) {
-      x <- binom.test(round(x / 100 * n_sim * 2), n_sim * 2, p = binom_test_correct, alternative = "greater")
+      x <- binom.test(round(x / 100 * n_sim * 2), 
+        n_sim * 2, 
+        p = binom_test_correct, 
+        alternative = "greater"
+      )
       round(x$p.value, 3)
     }
     out[["p_correct"]] <- sapply(out$Correct, b_test)
@@ -175,17 +187,28 @@ power_test <- function(design,
 
   if (is.numeric(ci)) {
     b_test <- function(x) {
-      x <- binom.test(round(x / 100 * n_sim), n_sim, p = binom_test, conf.level = ci, alternative = "two.sided")
+      x <- binom.test(round(x / 100 * n_sim), 
+        n_sim, 
+        p = binom_test, 
+        conf.level = ci, 
+        alternative = "two.sided"
+      )
       x$conf.int * 100
     }
     
     out[["Power lower"]] <- sapply(out$Power, function(x) b_test(x)[1])
     out[["Power upper"]] <- sapply(out$Power, function(x) b_test(x)[2])
-    out[["Alpha Error lower"]] <- sapply(out$"Alpha Error", function(x) b_test(x)[1])
-    out[["Alpha Error upper"]] <- sapply(out$"Alpha Error", function(x) b_test(x)[2])
+    out[["Alpha Error lower"]] <- sapply(out$"Alpha Error", 
+                                         function(x) b_test(x)[1])
+    out[["Alpha Error upper"]] <- sapply(out$"Alpha Error", 
+                                         function(x) b_test(x)[2])
       
     b_test <- function(x) {
-      x <- binom.test(round(x / 100 * n_sim * 2), n_sim * 2, p = binom_test, alternative = "two.sided")
+      x <- binom.test(round(x / 100 * n_sim * 2), 
+        n_sim * 2, 
+        p = binom_test, 
+        alternative = "two.sided"
+      )
       x$conf.int * 100
     }
     out[["Correct lower"]] <- sapply(out$Correct, function(x) b_test(x)[1])
@@ -231,9 +254,4 @@ power_test <- function(design,
   out
 }
 
-#' @rdname deprecated-functions
-#' @export
-power_testSC <- function(...) {
-  .deprecated_warning("power_test", "power_testSC")
-  power_test(...)
-}
+
